## `activities`

Adds the given activities to the feed and calls the specified callback

### Parameters

* `activities` **`Array`** Array of activities to add
* `callback` **`requestCallback`** Callback to call on completion



Returns `Promise` XHR request object


## `activities`

Updates all supplied activities on the getstream-io api

### Parameters

* `activities` **`array`** list of activities to update



Returns `Promise` 


## `activity`

Adds the given activity to the feed and
calls the specified callback

### Parameters

* `activity` **`object`** The activity to add
* `callback` **`requestCallback`** Callback to call on completion



Returns `Promise` Promise object


## `apiKey`

Initialize a client

### Parameters

* `apiKey` **`string`** the api key
* `apiSecret` **`[string]`** the api secret
* `appId` **`[string]`** id of the app
* `options` **`[object]`** additional options


### Examples

```js
<caption>initialize is not directly called by via stream.connect, ie:</caption>
stream.connect(apiKey, apiSecret)
```
```js
<caption>secret is optional and only used in server side mode</caption>
stream.connect(apiKey, null, appId);
```



## `appId`

Subscribes to any changes in the feed, return a promise

### Parameters

* `callback` **`function`** Callback to call on completion


### Examples

```js
feed.subscribe(callback).then(function(){
		console.log('we are now listening to changes');
});
```

Returns `Promise` Promise object


## `client`

Initialize a feed object

### Parameters

* `client` **`StreamClient`** The stream client this feed is constructed from
* `feedSlug` **`string`** The feed slug
* `userId` **`string`** The user id
* `token` **`[string]`** The authentication token





## `description`

Get the current user agent




Returns `string` current user agent


## `event`

Support for global event callbacks
This is useful for generic error and loading handling

### Parameters

* `event` **`string`** Name of the event
* `callback` **`function`** Function that is called when the event fires


### Examples

```js
client.on('request', callback);
client.on('response', callback);
```



## `feedId`

Returns a token that allows only read operations

### Parameters

* `feedSlug` **`string`** The feed slug to get a read only token for
* `userId` **`string`** The user identifier


### Examples

```js
client.getReadOnlyToken('user', '1');
```

Returns `string` token


## `feedId`

Returns a token that allows read and write operations

### Parameters

* `feedSlug` **`string`** The feed slug to get a read only token for
* `userId` **`string`** The user identifier


### Examples

```js
client.getReadWriteToken('user', '1');
```

Returns `string` token


## `identifier`

Removes the activity by activityId

### Parameters

* `activityId` **`string`** Identifier of activity to remove
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.removeActivity(activityId);
```
```js
feed.removeActivity({'foreign_id': foreignId});
```

Returns `Promise` Promise object


## `key`

Remove one or more event handlers

### Parameters

* `key` **`[string]`** Name of the handler


### Examples

```js
client.off() removes all handlers
client.off(name) removes the specified handler
```



## `options`

Returns a feed object for the given feed id and token

### Parameters

* `feedSlug` **`string`** The feed slug
* `userId` **`string`** The user identifier
* `token` **`[string]`** The token
* `siteId` **`[string]`** The site identifier
* `options` **`[object]`** Additional function options


### Examples

```js
client.feed('user', '1', 'token2');
```

Returns `StreamFeed` 


## `options`

List the followers of this feed

### Parameters

* `options` **`object`** Additional options
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.followers({limit:10, filter: ['user:1', 'user:2']}, callback);
```

Returns `Promise` Promise object


## `options`

Reads the feed

### Parameters

* `options` **`object`** Additional options
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.get({limit: 10, id_lte: 'activity-id'})
```
```js
feed.get({limit: 10, mark_seen: true})
```

Returns `Promise` Promise object


## `options`

List which feeds this feed is following

### Parameters

* `options` **`object`** Additional options
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.following({limit:10, filter: ['user:1', 'user:2']}, callback);
```

Returns `Promise` Promise object


## `process`

Create StreamClient

### Parameters

* `apiKey` **`string`** API key
* `apiSecret` **`[string]`** API secret (only use this on the server)
* `appId` **`[string]`** Application identifier
* `options` **`[object]`** Additional options


### Examples

```js
<caption>Basic usage</caption>
stream.connect(apiKey, apiSecret);
```
```js
<caption>or if you want to be able to subscribe and listen</caption>
stream.connect(apiKey, apiSecret, appId);
```
```js
<caption>or on Heroku</caption>
stream.connect(streamURL);
```
```js
<caption>where streamURL looks like</caption>
"https://thierry:pass@gestream.io/?app=1"
```

Returns `StreamClient` StreamClient


## `StreamClient`








## `StreamClient`



### Parameters

* `errors` **`[object]`** 
* `response` **`object`** 
* `body` **`object`** 





## `StreamClient`

Client to connect to Stream api






## `StreamFeed`

Manage api calls for specific feeds
The feed object contains convenience functions such add activity, remove activity etc






## `updateActivities`

Updates one activity on the getstream-io api

### Parameters

* `activity` **`object`** The activity to update



Returns `Promise` 


## `uri`

Creates a redirect url for tracking the given events in the context of
an email using Stream's analytics platform. Learn more at
getstream.io/personalization

### Parameters

* `targetUrl` **`string`** Target url
* `userId` **`string`** User id to track
* `events` **`array`** List of events to track



Returns `string` The redirect url


## `validateFeedSlug`

Unfollow the given feed

### Parameters

* `targetSlug` **`string`** Slug of the target feed
* `targetUserId` **`string`** [description]
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.unfollow('user', '2', callback);
```

Returns `object` XHR request object


## `validateFeedSlug`

Follows the given target feed

### Parameters

* `targetSlug` **`string`** Slug of the target feed
* `targetUserId` **`string`** User identifier of the target feed
* `options` **`object`** Additional options
* `callback` **`requestCallback`** Callback to call on completion


### Examples

```js
feed.follow('user', '1');
```
```js
feed.follow('user', '1', callback);
```
```js
feed.follow('user', '1', options, callback);
```

Returns `Promise` Promise object


